/*
 *  ZUC: Zaurus Unit Converter
 *  Copyright (C) 2002 Nicholas J Kreucher
 *
 *  This file is part of ZUC.
 *  
 *  ZUC is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  ZUC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with ZUC; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 */

#include "unitHistMenu.h"
#include <qobject.h>
#include <qpe/config.h>

/*
 * constructor
 */
unitHistMenu::unitHistMenu( QWidget * parent, const char * name )
	: QPopupMenu(parent, name)
{
	QString tmp;
	int i, count;
	Config *cf = new Config("ZUC");

	cf->setGroup("unitHist");

	count = cf->readNumEntry("count", 0);

	for(i = 0; i < count; i++)
	{
		section.append(cf->readEntry(tmp.sprintf("section%d", i), ""));
		fromUnit.append(cf->readEntry(tmp.sprintf("from%d", i), ""));
		toUnit.append(cf->readEntry(tmp.sprintf("to%d", i), ""));

		menusz.append(tmp.sprintf("%s -> %s",
					fromUnit[i].latin1(), toUnit[i].latin1()));

		insertItem(tmp);
	}

	delete cf;
}


/*
 * destructor
 */
unitHistMenu::~unitHistMenu()
{
	QString tmp;
	unsigned int i;
	Config *cf = new Config("ZUC");
	
	cf->setGroup("unitHist");

	cf->writeEntry("count", (int) section.count());
	
	for(i = 0; i < section.count(); i++)
	{
		cf->writeEntry(tmp.sprintf("section%d", i), section[i]);
	       	cf->writeEntry(tmp.sprintf("from%d", i), fromUnit[i]);
		cf->writeEntry(tmp.sprintf("to%d", i), toUnit[i]);
	}

	delete cf;
}


/*
 * inserts (or moves up) a history item
 */
int unitHistMenu::addHist(const QString &from, const QString &to,
	       const QString &sec)
{
	int i;
	QString tmp;
	const unsigned short max = 10;

	// see if the item is in there already
	tmp.sprintf("%s -> %s", from.latin1(), to.latin1());
	i = menusz.findIndex(tmp);

	// assume things can never get out of sync and units are section unique... heh ;)
	if( i != -1 && section[i] == sec )
	{
		// remove it first
		section.remove(section.at(i));
		toUnit.remove(toUnit.at(i));
		fromUnit.remove(fromUnit.at(i));

		// remove it from the menu too
		removeItemAt(i);
		menusz.remove(menusz.at(i));
	}
	else if( count() >= max )
	{
		// too many history items, chop off oldest
		section.remove(section.fromLast());
		toUnit.remove(toUnit.fromLast());
		fromUnit.remove(fromUnit.fromLast());
		menusz.remove(menusz.fromLast());

		removeItemAt(count()-1);
	}

	// add the item to the top of the list
	section.prepend(sec);
	toUnit.prepend(to);
	fromUnit.prepend(from);
	menusz.prepend(tmp);

	// add the item in the menu too
	return insertItem(tmp, 0, -1, 0);
}

