/*
 *  ZUC: Zaurus Unit Converter
 *  Copyright (C) 2002 Nicholas J Kreucher
 *
 *  This file is part of ZUC.
 *  
 *  ZUC is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  ZUC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with ZUC; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 */
#ifndef ZUC_H
#define ZUC_H
#include "zucui.h"
#include "conv_matrix.h"
#include "version.h"
#include <qlcdnumber.h>

#ifdef QPE
#include <qpe/qpeapplication.h>
#include <qpe/qpemenubar.h>
#elif KDE
#include <kapplication.h>
#include <kmenubar.h>
#else
#include <qapplication.h>
#include <qmenubar.h>
#endif

#define ZUCNAME "ZUC: Zaurus Unit Converter"

class QPopupMenu;
class unitHistMenu;

class zuc : public zucui
{ 
    Q_OBJECT

public:
    zuc( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~zuc();

private:
    long double result;
    conv_matrix *convit;
    int tempid, precision, idSwap;
#ifdef QPE
    QPEMenuBar *zuc_mb;
#elif KDE
    KMenuBar *zuc_mb;
#else
    QMenuBar *zuc_mb;
#endif
    QPopupMenu *units_menu;
    QPopupMenu *copy_menu;
    unitHistMenu *unitHist_menu;
    QPopupMenu *precision_menu;
    QPopupMenu *display_menu;
    void restoreLCD(QLCDNumber::Mode base=QLCDNumber::DEC, bool setBase = false);
    void parsePaste(QString);
    long double toPrecision(long double val);

private slots:
    void goodBye();
    void about();
    void aboutQt();
    void copyToClipboard();
    void copyToClipboard_nosz();
    void pasteFromClipboard();
    void swap_tofrom();
    void displayMenu(int id);

public slots:
    void switchSection(int);
    void switchSection(const char *);
    void setPrecision(int);
    void setUnitsFromHist(int i);
    void send_to_conv_me(QListBoxItem*);
    void do_conv_go();
    void lcd_overflow();
    void totd_go();

};

#endif // ZUC_H
