/*
 *  ZUC: Zaurus Unit Converter
 *  Copyright (C) 2002 Nicholas J Kreucher
 *
 *  This file is part of ZUC.
 *  
 *  ZUC is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  ZUC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with ZUC; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 */
#include "zuc_totd.h"
#include <qlabel.h>
#include <qstringlist.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qarray.h>
#include <stdlib.h>
	
/* 
 *  Constructs a zuc_totd which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
zuc_totd::zuc_totd( QWidget* parent, const char* name, bool modal, WFlags fl )
    : zuc_totdui( parent, name, modal, fl )
{
	tips.append(
		tr("<b>Tabbed Interface</b><br><br>Notice the main ZUC window has tabs along the bottom. This lets you switch between a big number display and a listing of current and past conversions."));

	tips.append(
		tr("<b>Base Conversion</b><br><br>You can easily do a standard base coversion for a result simply by clicking on the Hex, Dec, Oct or Bin options on the \"Big\" Tab.<br><br>Also, the input box will detect Hex as well as Dec:<br>Hex example: 0x1E"));

	tips.append(
		tr("<b>Super Paste</b><br><br>When pasting a value into ZUC from the Zaurus clipboard, ZUC will take any unit that procedes the number and try to find a matching unit for the currently selected category. Hit the \">\" button to try it out!"));

	tips.append(
		tr("<b>Super Copy</b><br><br>When copying a result from ZUC to the Zaurus clipboard, you can choose whether or not to include the unit after the number. This is handy when you might be pasting into a calculator or into a text editor to email your friend. Hit the \"<\" button to try it out!"));

	tips.append(
		tr("<b>Auto Digit Resize</b><br><br>If the result LCD panel is not large enough to display the result, ZUC will ask if you would like to reduce the display size of the digits to make the result fit... hows that!"));

	tips.append(
		tr("<b>Unit History</b><br><br>ZUC will remember your settings and recient conversion units used. Try the down arrow under the \"Go\" button..."));

	tips.append(
		tr("<b>Unit Swap</b><br><br>Need to swap the units in the from and to boxes? Click the swap button just to the left of the to/from dropdowns."));
	
	randomize();
	updateTip(0);
	totd_prev->setDisabled(true);
}


/*  
 *  Destroys the object and frees any allocated resources
 */
zuc_totd::~zuc_totd()
{
}

/*
 * "next" button slot
 */
void zuc_totd::next()
{
	if( currentTip+2 > tips.count()-1 )
		totd_next->setDisabled(true);

	if( currentTip == 0 )
		totd_prev->setEnabled(true);

	updateTip(currentTip+1);
}


/*
 * "prev" button slot
 */
void zuc_totd::prev()
{
	if( currentTip == 1 )
		totd_prev->setDisabled(true);

	if( currentTip == tips.count()-1 )
		totd_next->setEnabled(true);

	updateTip(currentTip-1);
}


/*
 * randomize tips
 */
void zuc_totd::randomize()
{
	unsigned int j, r;
	QString tmp;

	tipNum.fill( -1, tips.count() );

	for( j = 0; j < tips.count(); j++ )
	{
		r = (int) ( ((float)tips.count())*rand()/(RAND_MAX+1.0) );

		qDebug(tmp.sprintf("tipNum[%d] = %d", j, r));

		if( tipNum.find(r) != -1 )
			j--;
		else
			tipNum[j] = r;
	}
}


/*
 * changes the tipNumLabel and sets the tip text
 */
void zuc_totd::updateTip(int num)
{
	currentTip = num;
	tipLabel->setText(tips[tipNum[currentTip]]);

	// count the tips, and display in the tip counter
	tipNumLabel->setText(tr("Tip %1/%2").arg(currentTip+1).arg(tips.count()));
}

